@@ -1,22 +1,27 @@
 #
-# This file is part of Efforia project.
+# This file is part of Efforia Open Source Initiative.
 #
-# Copyright (C) 2011-2013 William Oliveira de Lagos <william@efforia.com.br>
+# Copyright (C) 2011-2014 William Oliveira de Lagos <william@efforia.com.br>
 #
-# Efforia is free software: you can redistribute it and/or modify
+# Shipping is free software: you can redistribute it and/or modify
 # it under the terms of the Lesser GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
-# Efforia is distributed in the hope that it will be useful,
+# Shipping is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU Lesser General Public License
-# along with Efforia. If not, see <http://www.gnu.org/licenses/>.
+# along with Shipping. If not, see <http://www.gnu.org/licenses/>.
 #
+#!/usr/bin/python
+# -*- coding: utf-8 -*-
 
 from django.conf.urls import patterns,url,include
 
-urlpatterns = patterns('shipping.views')
\ No newline at end of file
+urlpatterns = patterns('shipping.views',
+	("^$","main"),
+	("^mail","mail_send"),
+	)
\ No newline at end of file
